##############################
##2013 Prefresher
##Day 5 - Graphics in R
##Stephen Pettigrew
##Harvard University
##pettigrew@fas.harvard.edu
##############################


##### This R script shows how to do some basic graphics in R using
## functions in the base package. I don't get into GGPlot or any other
## graphics packages, although there's a lot of info available online
## about how to use them


## First let's read in some data to use:

setwd("c:/users/stephen/dropbox/gov prefresher/2014 prefresher/r tutorials")

load("day5data.RData")




## R  has canned functions for histograms, boxplots,
##and other types of plots:

hist(exampledata$x)

boxplot(exampledata$x)





## The most useful graphing function in R is plot()

## If you give plot just one numeric vector argument, it assumes that's 
## the y-coordinates, and it uses the index numbers of the vector (1,2,3,4...)
## as the x-coordinates:

plot(exampledata$x)



## If you want to create a bivariate plot of two numeric vectors, put the x variable
## first and the y variable second.

plot(exampledata$x,
     exampledata$y)



## You can add options to the plot() function to change how the graph looks:

## Add color to the points using the "col" option:
plot(exampledata$x,
     exampledata$y,
     col = "red")





## You can change the size of the symbols using the "cex" option:

plot(exampledata$x,
     exampledata$y,
     col = "red",
     cex = 3)

plot(exampledata$x,
     exampledata$y,
     col = "red",
     cex = .5)







## Change they type of symbol using the "pch" option:
plot(exampledata$x,
     exampledata$y,
     col = "red",
     pch = 8) ## stars

plot(exampledata$x,
     exampledata$y,
     col = "red",
     pch = 18) ## solid diamonds

## Here's a graph that shows you the 20 basic symbols:
## Googling "pch in r" will also give you websites with more symbol options

plot(1:21,
     rep(0, 21),
     pch = 0:20,
     cex = 2)






#### Most times, you'll want to tweak how the the actual graph itself looks, 
## Not just the points on it.


## You can change the x and y-axis labels using an option to plot()

plot(exampledata$x,
     exampledata$y,
     xlab = "X Variable",
     ylab = "Y Variable")







## You can also add a title to the top of the graph:

plot(exampledata$x,
     exampledata$y,
     xlab = "X Variable",
     ylab = "Y Variable",
     main = "Graph of Fake Data!")






## Another cool R trick (that lots of people don't know):
## Some functions will allow you to put "\n" into a character string
## and it'll wrap the text to the next line.
## Here's an example:

plot(exampledata$x,
     exampledata$y,
     xlab = "X Variable",
     ylab = "Y Variable",
     main = "Graph of Fake Data! \n Hooray!")






## You can also change the way the box around the plot looks.
## I personally am not a fan of the square box, so I use an 
## L shaped border when I graph:

plot(exampledata$x,
     exampledata$y,
     xlab = "X Variable",
     ylab = "Y Variable",
     main = "Graph of Fake Data! \n Hooray!",
     bty = "l")






## Once you have a plot opened, sometimes you want to add extra stuff to it

## One of the easiest things to add is a line using abline():

## Let's add a horizontal, blue, dashed line at y = 0 with a thickness of 3:

abline(h = 0, # horizonal line at 0
       col = "blue", # blue
       lty = 2, # 2 is dashed, 3 is dotted, etc.
       lwd = 3) # thickness or width of the line







## Now let's add a solid, red, line at x = 0 with a thickness of .5:

abline(v = 0, # vertical line at 0
       col = "red",
       lwd = .5)







## abline() can be also used to add straight lines that aren't horizontal or vertical:
## Remember how in middle school you learned that the function of a line is
## a + bx? Well abline functions the same way:

abline(a = 0,
       b = 6.2)









## Aside from adding lines to a plot, we can add more points to a plot using points()

points(exampledata$x,
       exampledata$z,
       col = "red",
       pch = 18)







## Let's say we wanted to connect all the red diamonds to the black circles that
## shared the same x value. We can do that with the segments() function.
## You'll use this function a lot to plot confidence intervals.

## segments() takes 4 arguments:
## segments(x1, y1, x2, y2)

segments(exampledata$x,
         exampledata$z,
         exampledata$x,
         exampledata$y)









## Another nice thing to add to plots is a legend.
## We do that with the legend() function.

## First let's get a clean plot:

plot(exampledata$x,
     exampledata$y,
     xlab = "X Variable",
     ylab = "Y Variable",
     main = "Graph of Fake Data! \n Hooray!",
     bty = "l")

points(exampledata$x,
       exampledata$z,
       col = "red",
       pch = 18)

legend("topright", ## location we want our legend
       legend = c("fake y variable", "fake z variable"), # labels that go into legend
       pch = c(1, 18), ## marker types associated with the labels I defined above
       col = c("black", "red"), ## colors associated with the labels I defined above
       bty = "n") ## turn off the box around the legend


## Notice that the legend isn't exactly in the best place. Instead of
## specifying "topright", "bottomleft", etc. we can give x,y coordinates for the legend.
## This often takes some playing around with though to get it right.
plot(exampledata$x,
     exampledata$y,
     xlab = "X Variable",
     ylab = "Y Variable",
     main = "Graph of Fake Data! \n Hooray!",
     bty = "l")

points(exampledata$x,
       exampledata$z,
       col = "red",
       pch = 18)

legend(x = 0, y = 25,
       legend = c("fake y variable", "fake z variable"),
       pch = c(1, 18),
       col = c("black", "red"),
       bty = "n")







## Sometimes you want to make a fancy axis.
## If you want to do this, often you want to turn off the axis at the beginning
## of your code, and then add it back later like this:

plot(exampledata$x,
     exampledata$y,
     xlab = "X Variable",
     ylab = "Y Variable",
     main = "Graph of Fake Data! \n Hooray!",
     bty = "l",
     xaxt = "n")## this makes the xaxis blank

axis(1, ##axis #1 is below the graph, 2 is left, 3 is above, 4 is right
     at = c(-1, 0, 1, 2),
     labels = c("Lebron", "Is", "The", "King"))



## We can do things like tilt the labels:

plot(exampledata$x,
     exampledata$y,
     xlab = "X Variable",
     ylab = "Y Variable",
     main = "Graph of Fake Data! \n Hooray!",
     bty = "l",
     xaxt = "n")## this makes the xaxis blank

axis(1,
     at = c(-1, 0, 1, 2),
     labels = c("Lebron", "Is", "The", "King"),
     las = 2)






######################################
## Exporting your graph to a file
######################################

## R is also really good at turning graphs into pdfs, jpegs, or other graphics.
## The key, though, with exporting any graph to a file is to add the line
## "graphics.off()" after the end of your graph so that R knows that it's
## done using that pdf, jpeg, or other file

pdf("fakedata.pdf")

plot(exampledata$x,
     exampledata$y,
     xlab = "X Variable",
     ylab = "Y Variable",
     main = "Graph of Fake Data! \n Hooray!",
     bty = "l",
     xaxt = "n")## this makes the xaxis blank

axis(1,
     at = c(-1, 0, 1, 2),
     labels = c("Lebron", "Is", "The", "King"),
     las = 2)

graphics.off()


jpeg("fakedata.jpg")

plot(exampledata$x,
     exampledata$y,
     xlab = "X Variable",
     ylab = "Y Variable",
     main = "Graph of Fake Data! \n Hooray!",
     bty = "l",
     xaxt = "n")## this makes the xaxis blank

axis(1,
     at = c(-1, 0, 1, 2),
     labels = c("Lebron", "Is", "The", "King"),
     las = 2)

graphics.off()







#######################################
## Multiple graphs on one figure
#######################################

## Another graph aspect of R is that it's easy to 
## put lots of graphics on one figure.
## We do this by manipulating the par() function using
## either the mfrow or mfcol options. 

## mfrow stands for multiframe by row
## mfcol stands for multigrame by column


## So let's say we wanted to plots side by side...

## First we start with this:

par(mfrow = c(1, 2))
## This tells R that we want a figure that'll have 1 row and 2 columns

## Now we can put the first plot

plot(exampledata$x,
     exampledata$y,
     xlab = "X Variable",
     ylab = "Y Variable",
     main = "Graph of Fake Data! \n Hooray!",
     bty = "l")


## Now the second

plot(exampledata$x,
     exampledata$z,
     xlab = "X Variable",
     ylab = "Z Variable",
     main = "Graph of Fake Data! \n Hooray!",
     bty = "l")






### Now for the rest of the time we have in here, I'm going to show you
## a graph and I want you to try to replicate it using the polls, returns, vote.totals
## objects in your workspace.

## The key will be to start very simply, i.e. just try to get the points on the graph
## in the right spots, labels the axes, etc. Then get fancy

## I was able to do it in 65 lines of code, not including spaces and comments.
















pdf("replication_graph.pdf",
    width = 12,
    height = 7.5)

par(mfrow = c(1,2))

## First start the graph and add red points for the states that 
## had < 50% democratic vote in 2008

plot(c(1:51)[returns$dpct08 < .5],
     returns$dpct08[returns$dpct08 < .5],
     ylim = c(0,1),
     bty = "l",
     xaxt = "n",
     xlab = "State",
     ylab = "Democratic Two-Party Vote Pct.",
     main = "Presidential Vote Totals \n by state",
     col = "red",
     pch = 18)

## Now add the 2008 states that had > 50%

points(c(1:51)[returns$dpct08 > .5],
       returns$dpct08[returns$dpct08 > .5],
       col = "blue",
       pch = 18)

## Now add the 2012 states that had < 50%

points(c(1:51)[returns$dpct12 < .5],
       returns$dpct12[returns$dpct12 < .5],
       col = "red",
       pch = 4)

## Now add the 2012 states that had > 50%

points(c(1:51)[returns$dpct12 > .5],
       returns$dpct12[returns$dpct12 > .5],
       col = "blue",
       pch = 4)

## Now add a black dividing line at 50%

abline(h = .5)

## Now let's add the x-axis labels by state names

axis(1,
     at = 1:51,
     labels = returns$state,
     cex.axis = .6,
     las = 3)

## Now let's add a legend. Actually two legends so they fit a little better

legend("bottomleft",
       legend = c("Dem% 08 in Dem State",
                  "Dem% 08 in GOP State",
                  "Dem% 12 in Dem State",
                  "Dem% 12 in GOP State"),
       col = c("blue", "red", "blue", "red"),
       pch = c(18, 18, 4, 4),
       bty = "n")







## Now let's do the second graph

## First make the variables we want:

plot(1, col = "white", ## this is a good hack to start a new plot with nothing on it
     xlim = c(1,max(polls[,1])),
     ylim = c(min(polls[,-1]), max(polls[,-1])),
     xlab = "Days until Election",
     ylab = "Obama and Romney Polling Percentages",
     main = "Daily Tracking Polls \n for 2012 Election",
     bty = "l")

## Now let's add Obama's polling margins
## We'll offset them by .1 so that they don't overlap with Romney's, once we add those

segments(polls$days.to.election - .15,
         polls$obama.min,
         polls$days.to.election - .15,
         polls$obama.max,
         col = "blue")

## Now let's add the Romney ones, again offsetting my .1

segments(polls$days.to.election +.15,
         polls$romney.min,
         polls$days.to.election + .15,
         polls$romney.max,
         col = "red")

## Add horizontal lines to indicate their actual vote totals

abline(h = vote.totals[1],
       col = "blue")
abline(h = vote.totals[2],
       col = "red")

## Add the actual vote percentage numbers to the right side of the graph

axis(4,
     at = vote.totals,
     labels = round(vote.totals, 1),
     las = 2,
     tick = F,
     cex.axis = .7)

graphics.off()